==> react-input-verification-code-2.0.0-9.tgz: package/lib/cjs/index.js <==
'use strict';

var React = require('react');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

var React__default = /*#__PURE__*/_interopDefaultLegacy(React);

function styleInject(css, ref) {
  if ( ref === void 0 ) ref = {};
  var insertAt = ref.insertAt;

  if (!css || typeof document === 'undefined') { return; }

  var head = document.head || document.getElementsByTagName('head')[0];
  var style = document.createElement('style');
  style.type = 'text/css';

  if (insertAt === 'top') {
    if (head.firstChild) {
      head.insertBefore(style, head.firstChild);
    } else {
      head.appendChild(style);
    }
  } else {
    head.appendChild(style);
  }

  if (style.styleSheet) {
    style.styleSheet.cssText = css;
  } else {
    style.appendChild(document.createTextNode(css));
  }
}

var css_248z = ".ReactInputVerificationCode-container {\n  display: flex;\n  gap: 0.5rem;\n}\n\n.ReactInputVerificationCode-item {\n  width: 4rem;\n  height: 4rem;\n  padding: 0;\n  border-radius: 4px;\n  font-size: 1.2rem;\n  text-align: center;\n  border: 0;\n  color: #555;\n  box-shadow: 0 0 0 1px #ccc;\n  outline: 0;\n  transition: box-shadow 0.2s ease-out;\n}\n\n.ReactInputVerificationCode-item:focus {\n  box-shadow: 0 0 0 2px #333;\n}\n";
styleInject(css_248z);

const ReactInputVerificationCode = ({ autoFocus = false, inputProps, length = 4, onChange = () => null, onCompleted = () => null, placeholder = '·', type = 'number', value: defaultValue = '', }) => {
    /**
     * generate a new array, map through it
     * and replace with the value when possible
     */
    const fillValues = React.useCallback((value) => new Array(length).fill('').map((_, index) => { var _a; return (_a = value[index]) !== null && _a !== void 0 ? _a : ''; }), [length]);
    const [values, setValues] = React.useState(fillValues(defaultValue));
    const [focusedIndex, setFocusedIndex] = React.useState(-1);
    const inputsRefs = React.useMemo(() => new Array(length).fill(null).map(() => React.createRef()), [length]);
    const validate = React.useCallback((input) => {
        if (type === 'number') {
            return /^\d/.test(input);
        }
        if (type === 'alphanumeric') {
            return /^[a-zA-Z0-9]/.test(input);
        }
        return true;
    }, [type]);
    const selectInputContent = React.useCallback((index) => {
        const input = inputsRefs[index].current;
        if (input) {
            requestAnimationFrame(() => {
                input.select();
            });
        }
    }, [inputsRefs]);
    const setValue = React.useCallback((value, index) => {
        const nextValues = [...values];
        nextValues[index] = value;
        setValues(nextValues);
        const stringifiedValues = nextValues.join('');
        const isCompleted = stringifiedValues.length === length;
        if (isCompleted) {
            onCompleted(stringifiedValues);
            return;
        }
        onChange(stringifiedValues);
    }, [length, onChange, onCompleted, values]);
    const focusInput = React.useCallback((index) => {
        var _a;
        const input = (_a = inputsRefs[index]) === null || _a === void 0 ? void 0 : _a.current;
        if (input) {
            requestAnimationFrame(() => {
                input.focus();
            });
        }
    }, [inputsRefs]);
    const blurInput = React.useCallback((index) => {
        var _a;
        const input = (_a = inputsRefs[index]) === null || _a === void 0 ? void 0 : _a.current;
        if (input) {
            requestAnimationFrame(() => {
                input.blur();
            });
        }
    }, [inputsRefs]);
    const onInputFocus = React.useCallback((index) => {
        var _a;
        const input = (_a = inputsRefs[index]) === null || _a === void 0 ? void 0 : _a.current;
        if (input) {
            setFocusedIndex(index);
            selectInputContent(index);
        }
    }, [inputsRefs, selectInputContent]);
    const onInputChange = React.useCallback((event, index) => {
        event.preventDefault();
        const eventValue = event.target.value;
        console.log('-------');
        console.log('RIVC:onInputChange', {
            event,
            eventValue,
            focusedIndex,
            index,
        });
        /**
         * otp code or pasted value
         */
        if (eventValue.length > 1) {
            console.log('RIVC: isOtp', true);
            console.log('RIVC: fillValues(eventValue)', fillValues(eventValue));
            setValues(fillValues(eventValue));
            const isCompleted = eventValue.length === length;
            console.log('RIVC: isCompleted', isCompleted);
            if (isCompleted) {
                onCompleted(eventValue);
                blurInput(index);
                return;
            }
            focusInput(eventValue.length);
            return;
        }
        console.log('RIVC: isOtp', false);
        /**
         * ensure we only display 1 character in the input
         * by clearing the already setted value
         */
        const value = eventValue.replace(values[index], '');
        /**
         * if the value is not valid, don't go any further
         * and select the content of the input for a better UX
         */
        if (!validate(value)) {
            selectInputContent(index);
            return;
        }
        console.log('RIVC', { value });
        setValue(value, index);
        /**
         * if the input is the last of the list
         * blur it, otherwise focus the next one
         */
        if (index === length - 1) {
            blurInput(index);
            return;
        }
        focusInput(index + 1);
    }, [
        blurInput,
        fillValues,
        focusInput,
        focusedIndex,
        length,
        onCompleted,
        selectInputContent,
        setValue,
        validate,
        values,
    ]);
    const onInputKeyDown = React.useCallback((event, index) => {
        const eventKey = event.key;
        if (eventKey === 'Backspace' || eventKey === 'Delete') {
            /**
             * prevent trigger a change event
             * `onInputChange` won't be called
             */
            event.preventDefault();
            setValue('', focusedIndex);
            focusInput(index - 1);
            return;
        }
        /**
         * since the value won't change, `onInputChange` won't be called
         * only focus the next input
         */
        if (eventKey === values[index]) {
            focusInput(index + 1);
        }
    }, [focusInput, focusedIndex, setValue, values]);
    /**
     * autoFocus
     */
    React.useEffect(() => {
        if (autoFocus) {
            focusInput(0);
        }
    }, [autoFocus, focusInput]);
    return (React__default["default"].createElement("div", { className: 'ReactInputVerificationCode-container' }, inputsRefs.map((ref, i) => (React__default["default"].createElement("input", Object.assign({ autoComplete: 'one-time-code', className: 'ReactInputVerificationCode-item', inputMode: type === 'number' ? 'numeric' : 'text', key: i, onChange: (event) => onInputChange(event, i), onFocus: () => onInputFocus(i), onKeyDown: (event) => onInputKeyDown(event, i), placeholder: placeholder, ref: ref, value: values[i] }, inputProps))))));
};

module.exports = ReactInputVerificationCode;

==> react-input-verification-code-2.0.0-10.tgz: package/lib/cjs/index.js <==
'use strict';

var React = require('react');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

var React__default = /*#__PURE__*/_interopDefaultLegacy(React);

function styleInject(css, ref) {
  if ( ref === void 0 ) ref = {};
  var insertAt = ref.insertAt;

  if (!css || typeof document === 'undefined') { return; }

  var head = document.head || document.getElementsByTagName('head')[0];
  var style = document.createElement('style');
  style.type = 'text/css';

  if (insertAt === 'top') {
    if (head.firstChild) {
      head.insertBefore(style, head.firstChild);
    } else {
      head.appendChild(style);
    }
  } else {
    head.appendChild(style);
  }

  if (style.styleSheet) {
    style.styleSheet.cssText = css;
  } else {
    style.appendChild(document.createTextNode(css));
  }
}

var css_248z = ".ReactInputVerificationCode-container {\n  display: flex;\n  gap: 0.5rem;\n}\n\n.ReactInputVerificationCode-item {\n  width: 4rem;\n  height: 4rem;\n  padding: 0;\n  border-radius: 4px;\n  font-size: 1.2rem;\n  text-align: center;\n  border: 0;\n  color: #555;\n  box-shadow: 0 0 0 1px #ccc;\n  outline: 0;\n  transition: box-shadow 0.2s ease-out;\n}\n\n.ReactInputVerificationCode-item:focus {\n  box-shadow: 0 0 0 2px #333;\n}\n";
styleInject(css_248z);

const ReactInputVerificationCode = ({ autoFocus = false, inputProps, length = 4, onChange = () => null, onCompleted = () => null, placeholder = '·', type = 'number', value: defaultValue = '', }) => {
    /**
     * generate a new array, map through it
     * and replace with the value when possible
     */
    const fillValues = (value) => new Array(length).fill('').map((_, index) => { var _a; return (_a = value[index]) !== null && _a !== void 0 ? _a : ''; });
    const [values, setValues] = React.useState(fillValues(defaultValue));
    const [focusedIndex, setFocusedIndex] = React.useState(-1);
    const inputsRefs = React.useMemo(() => new Array(length).fill(null).map(() => React.createRef()), [length]);
    const validate = (input) => {
        if (type === 'number') {
            return /^\d/.test(input);
        }
        if (type === 'alphanumeric') {
            return /^[a-zA-Z0-9]/.test(input);
        }
        return true;
    };
    const selectInputContent = (index) => {
        const input = inputsRefs[index].current;
        if (input) {
            requestAnimationFrame(() => {
                input.select();
            });
        }
    };
    const setValue = (value, index) => {
        const nextValues = [...values];
        nextValues[index] = value;
        setValues(nextValues);
        const stringifiedValues = nextValues.join('');
        const isCompleted = stringifiedValues.length === length;
        if (isCompleted) {
            onCompleted(stringifiedValues);
            return;
        }
        onChange(stringifiedValues);
    };
    const focusInput = React.useCallback((index) => {
        var _a;
        const input = (_a = inputsRefs[index]) === null || _a === void 0 ? void 0 : _a.current;
        if (input) {
            requestAnimationFrame(() => {
                input.focus();
            });
        }
    }, [inputsRefs]);
    const blurInput = (index) => {
        var _a;
        const input = (_a = inputsRefs[index]) === null || _a === void 0 ? void 0 : _a.current;
        if (input) {
            requestAnimationFrame(() => {
                input.blur();
            });
        }
    };
    const onInputFocus = (index) => {
        var _a;
        const input = (_a = inputsRefs[index]) === null || _a === void 0 ? void 0 : _a.current;
        if (input) {
            setFocusedIndex(index);
            selectInputContent(index);
        }
    };
    const onInputChange = (event, index) => {
        event.preventDefault();
        const eventValue = event.target.value;
        console.log('-------');
        console.log('RIVC:onInputChange', {
            event,
            eventValue,
            focusedIndex,
            index,
        });
        /**
         * otp code or pasted value
         */
        if (eventValue.length > 1) {
            console.log('RIVC: isOtp', true);
            console.log('RIVC: fillValues(eventValue)', fillValues(eventValue));
            setValues(fillValues(eventValue));
            const isCompleted = eventValue.length === length;
            console.log('RIVC: isCompleted', isCompleted);
            if (isCompleted) {
                onCompleted(eventValue);
                blurInput(index);
                return;
            }
            focusInput(eventValue.length);
            return;
        }
        console.log('RIVC: isOtp', false);
        /**
         * ensure we only display 1 character in the input
         * by clearing the already setted value
         */
        const value = eventValue.replace(values[index], '');
        /**
         * if the value is not valid, don't go any further
         * and select the content of the input for a better UX
         */
        if (!validate(value)) {
            selectInputContent(index);
            return;
        }
        console.log('RIVC', { value });
        setValue(value, index);
        /**
         * if the input is the last of the list
         * blur it, otherwise focus the next one
         */
        if (index === length - 1) {
            blurInput(index);
            return;
        }
        focusInput(index + 1);
    };
    const onInputKeyDown = (event, index) => {
        const eventKey = event.key;
        if (eventKey === 'Backspace' || eventKey === 'Delete') {
            /**
             * prevent trigger a change event
             * `onInputChange` won't be called
             */
            event.preventDefault();
            setValue('', focusedIndex);
            focusInput(index - 1);
            return;
        }
        /**
         * since the value won't change, `onInputChange` won't be called
         * only focus the next input
         */
        if (eventKey === values[index]) {
            focusInput(index + 1);
        }
    };
    /**
     * autoFocus
     */
    React.useEffect(() => {
        if (autoFocus) {
            focusInput(0);
        }
    }, [autoFocus, focusInput]);
    return (React__default["default"].createElement("div", { className: 'ReactInputVerificationCode-container' }, inputsRefs.map((ref, i) => (React__default["default"].createElement("input", Object.assign({ autoComplete: 'one-time-code', className: 'ReactInputVerificationCode-item', inputMode: type === 'number' ? 'numeric' : 'text', key: i, onChange: (event) => onInputChange(event, i), onFocus: () => onInputFocus(i), onKeyDown: (event) => onInputKeyDown(event, i), placeholder: placeholder, ref: ref, value: values[i] }, inputProps))))));
};

module.exports = ReactInputVerificationCode;
